==> thx_cron-0.3.5-py3-none-any.whl: thx/cron/management/commands/run_jobs.py <==
# -*- coding: utf-8 -*-
import logging
import time

from logging import StreamHandler

from django.conf import settings
from django.core.management.base import BaseCommand
from django.utils import timezone
from django.utils.translation import gettext_lazy as _

from ...models import Job
from ...models import JobLog


class Command(BaseCommand):
    logger = logging.getLogger('cron')
    help = _('Run Jobs')

    def add_arguments(self, parser):
        parser.add_argument(
            '-c', '--console', action='store_true', default=False,
            help='Debug - write logging to console',
        )
        parser.add_argument(
            '-l', '--debug-level', default='info',
            help='Set debug level (debug, info, warnings) for console',
        )
        parser.add_argument(
            '-s', '--status', type=int, required=False,
            choices=[value[0] for value in settings.CRON_JOB_STATUS_CHOICES])
        parser.add_argument(
            '-d', '--datetime', required=False,
            type=lambda d: timezone.datetime.strptime(d, '%Y-%m-%dT%H:%M'))
        parser.add_argument(
            '-D', '--delay', default=20, type=int,
            help='set delay in seconds from a job to another',
        )
        parser.add_argument(
            '-r', '--restart', action='store_true', default=False,
            help='restart if blocked during execution by user. Useful for debugging',
        )

    def handle(self, *args, **options):
        debug_level = getattr(logging, options.get('debug_level').upper())
        self.logger.setLevel(debug_level)
        self.logger.handlers[0].setLevel(debug_level)

        if options.get('console'):
            console_handler = StreamHandler()
            console_handler.setLevel(debug_level)
            self.logger.addHandler(console_handler)
            self.logger.setLevel(debug_level)

        restart_if_keyboard_interrupt = options.get('restart')

        parameters = {}
        try:
            if options['datetime']:
                parameters['datetime'] = options['datetime']
            Job.complete_old_jobs(**parameters)

            if options['status']:
                parameters['status'] = options['status']
            jobs = Job.selected_jobs(**parameters)

            delay = options['delay']

            self.logger.info("Start CRON Jobs")
            for num, job in enumerate(jobs):
                # check if the job still has the exact status to be launched
                if not Job.objects.get(pk=job.pk).status == parameters.get('status', 0):
                    continue
                self.run(job, restart_if_keyboard_interrupt)
                if jobs.count() < num + 1:
                    time.sleep(delay)
            
            Job.verify_old_jobs_and_send_alert_if_necessary()
            self.logger.info("End CRON Jobs")

        except Exception as e:
            self.logger.error(f"Failed run jobs: {e}")
            self.stdout.write(self.style.ERROR(
                f'Execution failed: {e}')
            )

    def run(self, job, restart_if_keyboard_interrupt: bool = False):
        self.logger.info("Job {} (id {})started".format(job.name, job.id))
        try:
            job.set_running()
            result = job.run_command()
            new_elaboration = JobLog.objects.create(
                job=job,
                elaboration_time=result.elaboration_time,
                elaboration_results=result.elaboration_results,
                extra_info=getattr(result, 'extra_info', None),
                is_valid=result.is_valid,
                log_file_content=getattr(result, 'log_file_content', None)
            )
            new_elaboration.save()
            if job.is_ripetitive:
                job.set_to_run()
            else:
                job.set_completed()
            self.logger.info("Job {} (id {}) completed".format(job.name, job.id))
        except Exception as e:
            job.set_error({'error': e})
            self.logger.error("Job {} error: {}".format(job.name, e))
            # raise
        except KeyboardInterrupt as e:
            self.logger.info("Job {}. Job execution interrupted by user ...".format(job.name))
            if restart_if_keyboard_interrupt:
                try:
                    job.set_to_run()
                except Exception as e:
                    self.logger.error(e)
            else:
                job.set_error({'error': e})

==> thx_cron-0.4.4-py3-none-any.whl: thx/cron/management/commands/run_jobs.py <==
# -*- coding: utf-8 -*-
import logging
import time

from logging import StreamHandler

from django.conf import settings
from django.core.management.base import BaseCommand
from django.utils import timezone
from django.utils.translation import gettext_lazy as _

from ...models import Job
from ...models import JobLog


class Command(BaseCommand):
    logger = logging.getLogger('cron')
    help = _('Run Jobs')

    def add_arguments(self, parser):
        parser.add_argument(
            '-c', '--console', action='store_true', default=False,
            help='Debug - write logging to console',
        )
        parser.add_argument(
            '-l', '--debug-level', default='info',
            help='Set debug level (debug, info, warnings) for console',
        )
        parser.add_argument(
            '-s', '--status', type=int, required=False,
            choices=[value[0] for value in settings.CRON_JOB_STATUS_CHOICES])
        parser.add_argument(
            '-d', '--datetime', required=False,
            type=lambda d: timezone.datetime.strptime(d, '%Y-%m-%dT%H:%M'))
        parser.add_argument(
            '-D', '--delay', default=20, type=int,
            help='set delay in seconds from a job to another',
        )
        parser.add_argument(
            '-r', '--restart', action='store_true', default=False,
            help='restart if blocked during execution by user. Useful for debugging',
        )

    def handle(self, *args, **options):
        debug_level = getattr(logging, options.get('debug_level').upper())
        self.logger.setLevel(debug_level)
        self.logger.handlers[0].setLevel(debug_level)

        if options.get('console'):
            console_handler = StreamHandler()
            console_handler.setLevel(debug_level)
            self.logger.addHandler(console_handler)
            self.logger.setLevel(debug_level)

        restart_if_keyboard_interrupt = options.get('restart')

        parameters = {}
        try:
            if options['datetime']:
                parameters['datetime'] = options['datetime']
            Job.complete_old_jobs(**parameters)

            if options['status']:
                parameters['status'] = options['status']
            jobs = Job.selected_jobs(**parameters)

            delay = options['delay']

            self.logger.info("Start CRON Jobs")
            for num, job in enumerate(jobs):
                # check if the job still has the exact status to be launched
                if not Job.objects.get(pk=job.pk).status == parameters.get('status', 0):
                    continue
                self.run(job, restart_if_keyboard_interrupt)
                if jobs.count() < num + 1:
                    time.sleep(delay)
            
            Job.verify_old_jobs_and_send_alert_if_necessary()
            self.logger.info("End CRON Jobs")

        except Exception as e:
            self.logger.error(f"Failed run jobs: {e}")
            self.stdout.write(self.style.ERROR(
                f'Execution failed: {e}')
            )

    def run(self, job, restart_if_keyboard_interrupt: bool = False):
        self.logger.info("Job {} (id {})started".format(job.name, job.id))
        try:
            job.set_running()
            result = job.run_command()
            JobLog.objects.create(
                job=job,
                elaboration_time=result.elaboration_time,
                elaboration_results=result.elaboration_results or {},
                extra_info=getattr(result, 'extra_info', None),
                is_valid=result.is_valid,
                log_file_content=getattr(result, 'log_file_content', None)
            )
            if job.is_ripetitive:
                job.set_to_run()
            else:
                job.set_completed()
            self.logger.info("Job {} (id {}) completed".format(job.name, job.id))
        except Exception as e:
            job.set_error({'error': e})
            self.logger.error("Job {} error: {}".format(job.name, e))
            self.logger.exception(e)
            # raise
        except KeyboardInterrupt as e:
            self.logger.info("Job {}. Job execution interrupted by user ...".format(job.name))
            if restart_if_keyboard_interrupt:
                try:
                    job.set_to_run()
                except Exception as e:
                    self.logger.error(e)
            else:
                job.set_error({'error': e})
